Index: trunk/psLib/test/astronomy/tst_psAstrometry01.c
===================================================================
--- trunk/psLib/test/astronomy/tst_psAstrometry01.c	(revision 3769)
+++ trunk/psLib/test/astronomy/tst_psAstrometry01.c	(revision 3882)
@@ -5,6 +5,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.25 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-04-26 19:53:30 $
+*  @version $Revision: 1.26 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-05-11 21:49:01 $
 *
 * XXX: Must test
@@ -21,4 +21,6 @@
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
 */
+
+#include <stdlib.h>
 
 #include "psTest.h"
@@ -797,6 +799,6 @@
     for (psS32 x = 0 ; x < TST05_X_POLY_ORDER ; x++) {
         for (psS32 y = 0 ; y < TST05_Y_POLY_ORDER ; y++) {
-            transInit->x->coeff[x][y] = ((psF32) (random() % 1000000)) / 100000.0;
-            transInit->y->coeff[x][y] = ((psF32) (random() % 1000000)) / 100000.0;
+            transInit->x->coeff[x][y] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
+            transInit->y->coeff[x][y] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
         }
     }
@@ -954,13 +956,13 @@
     for (psS32 n = 0 ; n < 100 ; n++) {
         //
         // We create a random linear transformation and hope it is invertible.
         //
-        trans->x->coeff[0][0] = ((psF32) (random() % 1000000)) / 100000.0;
-        trans->x->coeff[0][1] = ((psF32) (random() % 1000000)) / 100000.0;
-        trans->x->coeff[1][0] = ((psF32) (random() % 1000000)) / 100000.0;
+        trans->x->coeff[0][0] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
+        trans->x->coeff[0][1] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
+        trans->x->coeff[1][0] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
         trans->x->coeff[1][1] = 0.0;
-        trans->y->coeff[0][0] = ((psF32) (random() % 1000000)) / 100000.0;
-        trans->y->coeff[0][1] = ((psF32) (random() % 1000000)) / 100000.0;
-        trans->y->coeff[1][0] = ((psF32) (random() % 1000000)) / 100000.0;
+        trans->y->coeff[0][0] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
+        trans->y->coeff[0][1] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
+        trans->y->coeff[1][0] = (psF32)rand() / (psF32)RAND_MAX * 10.0f;
         trans->y->coeff[1][1] = 0.0;
 
@@ -954,13 +956,13 @@
     for (psS32 n = 0 ; n < 100 ; n++) {
         //
-        // We create a random linear transformation and hope it is invertible.
+        // We create a rand() linear transformation and hope it is invertible.
         //
